@@ -2,6 +2,7 @@
 Python wrapper for getting air quality data from GIOS.
 """
 import logging
+from contextlib import suppress
 from typing import Any, Dict, List, Optional, cast
 
 from aiohttp import ClientSession
@@ -72,12 +73,12 @@ class Gios:  # pylint:disable=(too-few-public-methods
         # The GIOS server sends a null values for sensors several minutes before
         # adding new data from measuring station. If the newest value is null
         # we take the earlier value.
-        for sensor in data:
+        for sensor, sensor_data in data.items():
             try:
                 if sensors[sensor]["values"][0][ATTR_VALUE]:
-                    data[sensor][ATTR_VALUE] = sensors[sensor]["values"][0][ATTR_VALUE]
+                    sensor_data[ATTR_VALUE] = sensors[sensor]["values"][0][ATTR_VALUE]
                 elif sensors[sensor].get("values")[1][ATTR_VALUE]:
-                    data[sensor][ATTR_VALUE] = sensors[sensor]["values"][1][ATTR_VALUE]
+                    sensor_data[ATTR_VALUE] = sensors[sensor]["values"][1][ATTR_VALUE]
                 else:
                     invalid_sensors.append(sensor)
             except (IndexError, KeyError, TypeError):
@@ -92,19 +93,14 @@ class Gios:  # pylint:disable=(too-few-public-methods
 
         indexes = await self._get_indexes()
 
-        try:
-            for sensor in data:
-                index_level = ATTR_INDEX_LEVEL.format(sensor.lower().replace(".", ""))
-                data[sensor][ATTR_INDEX] = indexes[index_level][
-                    "indexLevelName"
-                ].lower()
-
+        with suppress(IndexError, KeyError, TypeError):
             data[ATTR_AQI.lower()] = {ATTR_NAME: ATTR_AQI}
             data[ATTR_AQI.lower()][ATTR_VALUE] = indexes["stIndexLevel"][
                 "indexLevelName"
             ].lower()
-        except (IndexError, KeyError, TypeError) as err:
-            raise InvalidSensorsData("Invalid index data from GIOS API") from err
+            for sensor, sensor_data in data.items():
+                index_level = ATTR_INDEX_LEVEL.format(sensor.lower().replace(".", ""))
+                sensor_data[ATTR_INDEX] = indexes[index_level]["indexLevelName"].lower()
         return data
 
     async def _get_stations(self) -> List[Dict[str, Any]]:
